class EcoindexContentTypeError(Exception):
    pass


class EcoindexHostUnreachable(Exception):
    pass


class EcoindexPageNotFound(Exception):
    pass


class EcoindexStatusError(Exception):
    pass


class EcoindexTimeout(Exception):
    pass
